﻿--[[
	This file is part of PlayerZone AddOn for WoW 3.3.5a
	
	This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
	
	Copyright © 2017 Yulemath
]]

-- Loading MetaDatas

PlayerZone_VERSION = GetAddOnMetadata("PlayerZone", "Version")
PlayerZone_AUTHOR = GetAddOnMetadata("PlayerZone", "Author")
PlayerZone_XDATE = GetAddOnMetadata("PlayerZone", "X-Date")
PlayerZone_XWEBSITE = GetAddOnMetadata("PlayerZone", "X-Website")

local PlayerZone = LibStub("AceAddon-3.0"):NewAddon("PlayerZone", "AceConsole-3.0", "AceEvent-3.0")
local L = LibStub("AceLocale-3.0"):GetLocale("PlayerZone")

local defaults = {
	profile = {
		mainS = true,
		wmS = true,
		coords = true,
		lock = false,
		pluginLDB = {},
		plugin = true,
		color = {
			r = 0,
			g = 0,
			b = 0,
			a = 0,
		},
		mainPos = {
			anchor = "TOP",
			relF = UIParent,
			relP = "TOP",
			x = 0,
			y = 0,
		},
		levelF = true,
		font = {
			list = {
			"BlackChancery",
			"rm_midse",
			"Tw_Cen_MT_Bold",
			"Ultima_Campagnoli",
			"VeraSe",
			"ABF",
			"Accidental Presidency",
			"Adventure",
			"Avqest",
			"Bazooka",
			"BigNoodleTitling",
			"BigNoodleTitling-Oblique",
			"Emblem",
			"Enigma__2",
			"Tangerin",
			"Movie_Poster-Bold",
			"Porky",
			"Yellowjacket",
			"Bleeding_Cowboys",
			"CAROLU__",
			"Faith_Collapsing",
			},
			v = 4,
			selected = "Ultima_Campagnoli",
			size = 12,
		},
		texture = {
			list = {
				"Glue-Tooltip-Border",
				"LFGBorder",
				"TextPanel-Border",
				"UI-Tooltip-Border",
				"UI-TextBackground-Backdrop",
				},
				v = 3,
				selected = "TextPanel-Border",
		}
	}
}

function PlayerZone:OnInitialize()

	self.db = LibStub("AceDB-3.0"):New("PlayerZoneDB", defaults, true)
	
	self:SetupOptions()

end

function PlayerZone:OnEnable()
	-- Register Events
	self:RegisterEvent("ZONE_CHANGED_NEW_AREA", "ZoneUpdate")
	self:RegisterEvent("ZONE_CHANGED", "ZoneUpdate")
	self:RegisterEvent("VIARIABLES_LOADED", "ZoneUpdate")
	self:RegisterEvent("ZONE_CHANGED_INDOORS", "ZoneUpdate")
	self:RegisterEvent("UPDATE_INSTANCE_INFO", "ZoneUpdate")
	
	self:CreateFrames()
	self:OptionsChanged()
	self:LoadFramesScripts()
	self:Print("Version (|cff00ff00"..PlayerZone_VERSION..L["|r) Chargée."])
	
end

function PlayerZone:CreateFrames()
local db = self.db.profile
	-- Creating Main Frame
local function MainFrame()
	local f = CreateFrame("Frame", "PlayerZoneFrame", db.mainPos.relF)
		f:SetFrameStrata("MEDIUM")
		f:SetMovable(true)
		f:EnableMouse(true)
		f:SetClampedToScreen(true)
		f:RegisterForDrag("LeftButton")
		f:SetPoint(db.mainPos.anchor, db.mainPos.x, db.mainPos.y)
		f:SetHeight(35)
		f:SetWidth(220)
		
		-- FontStrings
		local fs = f:CreateFontString("PlayerZoneFrameText1", "OVERLAY", "GameFontHighlightSmall")
		local fs2 = f:CreateFontString("PlayerZoneFrameText2", "OVERLAY", "GameFontHighlightSmall")
		return f
end

	-- Creating Level Frame
local function LevelFrame()
	local f = CreateFrame("Frame", "PlayerZoneLevelFrame", UIParent)
		f:SetFrameStrata("MEDIUM")
		f:SetMovable(true)
		f:EnableMouse(true)
		f:SetClampedToScreen(true)
		f:SetPoint("TOP", PlayerZoneFrame, "BOTTOM")
		f:SetHeight(25)
		f:SetWidth(60)

	local fs = f:CreateFontString("PlayerZoneLevelText", "OVERLAY", "GameFontHighlightSmall")
	return f
end
		
	-- Creating Coords
local function CoordsFrame()
	local f = CreateFrame("Frame", "PlayerZoneCoordsFrame", WorldMapFrame)
		f:SetPoint("BOTTOMLEFT", WorldMapFrame, "BOTTOMLEFT")
		
	local fs = f:CreateFontString("PlayerZoneCoordsText1", "OVERLAY", "GameFontNormal")
		fs:SetPoint("BOTTOMLEFT", WorldMapPositioningGuide, "BOTTOMLEFT", 20, 10)
		fs:SetText(L["Position du joueur :"])
		fs:SetTextColor(0, 0.6, 0.8)
		
	local fs2 = f:CreateFontString("PlayerZoneCoordsText2", "OVERLAY", "GameFontNormal")
		fs2:SetPoint("BOTTOMLEFT", WorldMapPositioningGuide, "BOTTOMLEFT", 125, 10)
		fs2:SetTextColor(0, 1, 0.4)
	return f
end
	
	-- Creating Plugin
local function PluginFrame()
	local object = {
		type = "launcher",
		icon = "Interface\\WorldMap\\WorldMap-Icon",
		label = "PlayerZone",
		OnClick = function(self, button)
			if ( InterfaceOptionsFrame:IsShown() ) then
				InterfaceOptionsFrame:Hide()
			else
				InterfaceOptionsFrame_OpenToCategory(PlayerZone.optionsFrames.Options)
				InterfaceOptionsFrame_OpenToCategory(PlayerZone.optionsFrames.PlayerZone)
				PlaySound("igCharacterInfoTab")
			end
		end,
		OnTooltipShow = function(tooltip)
			tooltip:AddLine("PlayerZone")
			tooltip:AddLine(L["|cffffffffCliquer pour afficher les options|r"])
		end,
	}
	LibStub("LibDataBroker-1.1"):NewDataObject("PlayerZonePlugin", object)
	LibStub("LibDBIcon-1.0"):Register("PlayerZonePlugin", object, db.pluginLDB)
end
	
	-- Creating World Map Frame
local function WorldMapFrame()
	local f = CreateFrame("Frame", "PlayerZoneWMB", WorldMapButton)
		f:SetPoint("TOP", WorldMapButton, "TOP")
	
	local fs = f:CreateFontString("PlayerZoneWMBText", "OVERLAY", "GameFontNormalLarge")
		fs:SetPoint("TOP", WorldMapPositioningGuide, "TOP", 0, -80)
	return f
end
	
	-- Creating World Map Instances Frame
local function DungeonsFrame()
	local f = CreateFrame("Frame", "PlayerZoneWMIFrame", WorldMapButton)
		f:SetPoint("TOPLEFT", WorldMapButton, "TOPLEFT", -2, 2)
	-- Foot Frame
	local f2 = CreateFrame("Frame", "PlayerZoneFrameFoot", PlayerZoneWMIFrame)
		f2:SetHeight(32)
		f2:SetWidth(128)
	local texture = f2:CreateTexture()
		texture:SetAllPoints(f2)
		texture:SetTexture("Interface\\AddOns\\PlayerZone\\Artworks\\GoldHeader.tga")
	local fS = f2:CreateFontString("PlayerZoneFootText", "OVERLAY", "GameFontHighlight")
		fS:SetPoint("CENTER", 0, 0.5)
		fS:SetText("")
	return f, f2
end
	
	-- Loading Frames
			MainFrame()
			LevelFrame()
			CoordsFrame()
			PluginFrame()
			WorldMapFrame()
			DungeonsFrame()
			
end

function PlayerZone:CreateInstanceFrame(frame)
				
		-- Instances Header
		if ( frame == "Instance" ) then
			local f = CreateFrame("Frame", "PlayerZoneInstanceHeader", PlayerZoneWMIFrame)
			f:SetHeight(32)
			f:SetWidth(128)
			f:SetPoint("TOP", PlayerZoneWMIFrame, "TOP")
			local teX = f:CreateTexture()
			teX:SetAllPoints(f)
			teX:SetTexture("Interface\\AddOns\\PlayerZone\\Artworks\\GoldHeader.tga")
			local fS = f:CreateFontString("PlayerZoneInstanceHeaderText", "OVERLAY", "GameFontHighlight")
			fS:SetPoint("CENTER", 0, 0.5)
			fS:SetText(L["Instances"])
		
		-- Instances Body Frame

			local f1 = CreateFrame("Frame", "PlayerZoneInstanceBody", f)
			f1:SetPoint("TOP", f, "BOTTOM", 0, 4)
			f1:SetBackdrop( { 
				bgFile = "Interface\\Tooltips\\UI-Tooltip-Background", 
				edgeFile = "Interface\\DialogFrame\\UI-DialogBox-Border.blp", tile = false, tileSize = 16, edgeSize = 16, 
				insets = { left = 4, right = 4, top = 4, bottom = 4 }
			})
			f1:SetBackdropColor(0, 0, 0, 0.8)
			return
		end
		
		-- Raid Header
		if ( frame == "Raid" ) then
			local f = CreateFrame("Frame", "PlayerZoneRaidHeader", PlayerZoneWMIFrame)
			f:SetHeight(32)
			f:SetWidth(128)
			if ( PlayerZoneInstanceHeader ) then
				f:SetPoint("TOP", PlayerZoneInstanceBody, "BOTTOM")
			else
				f:SetPoint("TOP", PlayerZoneWMIFrame, "TOP")
			end
			local teX = f:CreateTexture()
			teX:SetAllPoints(f)
			teX:SetTexture("Interface\\AddOns\\PlayerZone\\Artworks\\GoldHeader.tga")
			local fS = f:CreateFontString("PlayerZoneRaidHeaderText", "OVERLAY", "GameFontHighlight")
			fS:SetPoint("CENTER", 0, 0.5)
			fS:SetText("Raids")
			
		-- Raid Body
			local f1 = CreateFrame("Frame", "PlayerZoneRaidBody", f)
			f1:SetPoint("TOP", f, "BOTTOM", 0, 4)
			f1:SetBackdrop( { 
				bgFile = "Interface\\Tooltips\\UI-Tooltip-Background", 
				edgeFile = "Interface\\DialogFrame\\UI-DialogBox-Border.blp", tile = false, tileSize = 16, edgeSize = 16, 
				insets = { left = 4, right = 4, top = 4, bottom = 4 }
			})
			f1:SetBackdropColor(0, 0, 0, 0.8)
			return
		end
		
		
	
end


function PlayerZone:DeleteFrame(f)
	if ( not f ) then return end
    local name, cache = f:GetName(), {}
    f:Hide()
    f:SetParent(nil)
    f:UnregisterAllEvents()
    f:SetID(0)
    f:ClearAllPoints()
    if name then
        _G[name] = nil
    end
    tinsert(cache, f)
end

function PlayerZone:InstanceFontString(key, text, levelMin, levelMax, hero, heroLevel, frame)
	local heroText, w, w2, h, y
	if ( hero ) then heroText = L["  \|  Héroïque : "]..heroLevel else heroText = "" end
	fS = frame:CreateFontString("", "OVERLAY", "GameFontHighlightSmall")
	fS:SetText(text.." : |cff00aaff"..levelMin.." - "..levelMax.."|r "..heroText)
	y = ((fS:GetHeight() + 8) * (key - 1)) + 8
	fS:SetPoint("TOPLEFT", frame, "TOPLEFT", 7, -y)
	h = fS:GetHeight()
	w = frame:GetWidth()
	w2 = fS:GetWidth() + 15
	if ( w2 > w or not w ) then frame:SetWidth(w2) end
	return h, y
end

function PlayerZone:RaidFontString(key, text, level, mod_, heroic, difficulty, frame)
	local heroText, w, w2, h, y
	if ( heroic ) then hero = L["Oui"] else hero = L["Non"] end
	fS = frame:CreateFontString("", "OVERLAY", "GameFontHighlightSmall")
	fS:SetText(text.." : |cff00aaff"..level..L["|r  \|  Joueurs : "]..mod_..L["  \|  Héroïque : "]..hero..L["  \|  Difficulté : "]..difficulty.."/5")
	y = ((fS:GetHeight() + 8) * (key - 1)) + 8
	fS:SetPoint("TOPLEFT", frame, "TOPLEFT", 7, -y)
	h = fS:GetHeight()
	w = frame:GetWidth()
	w2 = fS:GetWidth() + 15
	if ( w2 > w or not w ) then frame:SetWidth(w2) end
	return h, y
end