﻿--[[
	This file is part of PlayerZone AddOn for WoW 3.3.5a
	
	This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
	
	Copyright © 2017 Yulemath
]]

local PlayerZone = LibStub("AceAddon-3.0"):GetAddon("PlayerZone")
local L = LibStub("AceLocale-3.0"):GetLocale("PlayerZone")


function PlayerZone:LoadFramesScripts()
	local db = self.db.profile
	local wmF, mainF, coordsF, coordsFS2 = PlayerZoneWMB, PlayerZoneFrame, PlayerZoneCoordsFrame, PlayerZoneCoordsText2
	
	coordsF:SetScript("OnUpdate", function()
		local function round(num, idp)
			local mult = 10 ^ (idp or 0)
			return math.floor(num * mult + 5) / mult
		end
		local x, y = GetPlayerMapPosition("player")
		local text
		if ( x == 0 and y == 0 ) then
			text = realZoneName
		else
			x = round(x * 100, 2)
			y = round(y * 100, 2)
			text = string.format("%.2f - %.2f", x, y)
			coordsFS2:SetText(text)
		end
	end)
	
	mainF:SetScript("OnDragStart", function() if ( not db.lock ) then mainF:StartMoving() end end)
	mainF:SetScript("OnDragStop", function ()
		mainF:StopMovingOrSizing()
		db.mainPos.anchor, db.mainPos.relF, db.mainPos.relP, db.mainPos.x, db.mainPos.y = mainF:GetPoint()
	end)
	mainF:SetScript("OnHide", mainF.StopMovingOrSizing)
	
	wmF:SetScript("OnUpdate", function() PlayerZone:WorldMapUpdate() end)
	
end

function PlayerZone:ZoneUpdate()
local db = self.db.profile
local zone, subZone, fS1, fS2, f = GetZoneText(), GetSubZoneText(), PlayerZoneFrameText1, PlayerZoneFrameText2, PlayerZoneLevelFrame
local inInstance, instanceType = IsInInstance()
local areaID = GetCurrentMapAreaID()

	if ( not f:IsShown() ) then
		f:Show()
		db.levelF = true
	end
	
	fS1:SetText(zone)
	fS2:SetText(subZone)
	
	if ( inInstance ) then
		self:OnEnteringDungeons(fS1, fS2)
	elseif ( areaID == 15 or areaID == 14 ) then
		f:Hide()
		db.levelF = false
		fS1:SetTextColor(0, 0.8, 1)
		fS2:SetTextColor(0, 0.8, 1)
	else
		self:GetZoneLevel()
	end
	
	PlayerZone:OptionsChanged(db)
	self:SetFrameSize()	
end

function PlayerZone:OnEnteringDungeons(fS1, fS2)

	local fS3 = PlayerZoneLevelText
	local name, type, difficultyIndex, difficultyName, maxPlayers,
    dynamicDifficulty, isDynamic, instanceMapId = GetInstanceInfo()
	
	if ( type == "party" ) then
		if ( difficultyIndex == 1 ) then
			fS3:SetText("Normal")
			fS3:SetTextColor(1, 1, 0)
		elseif ( difficultyIndex == 2 ) then
			fS3:SetText(L["Héroïque"])
			fS3:SetTextColor(1, 0, 0)
		end
		fS1:SetTextColor(1, 1, 1)
		fS2:SetTextColor(1, 1, 1)
	elseif ( type == "raid" ) then
		fS3:SetText(difficultyName)
		if ( difficultyIndex == 1 ) then
			fS3:SetTextColor(1, 1, 0)
		elseif ( difficultyIndex == 2 ) then
			fS3:SetTextColor(1, 1, 0)
		elseif ( difficultyIndex == 3 ) then
			fS3:SetTextColor(1, 0, 0)
		elseif ( difficultyIndex == 4 ) then
			fS3:SetTextColor(1, 0, 0)
		end
		fS1:SetTextColor(1, 1, 1)
		fS2:SetTextColor(1, 1, 1)
	end
end
